Executor class abstract
Abstract class that defines the interface for the execute() and
query*() methods.
Implemented by Client and Transaction.
- Implementers
Constructors
- Executor()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
String query, [dynamic args]) → Future< void> - Executes a query, returning no result.
-
executeSQL(
String query, [dynamic args]) → Future< void> - Executes a SQL query, returning no result.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
String query, [dynamic args]) → Future< List> -
Executes a query, returning a
Listof results. -
queryJSON(
String query, [dynamic args]) → Future< String> -
Executes a query, returning the result as a JSON encoded
String. -
queryRequiredSingle(
String query, [dynamic args]) → Future -
Executes a query, returning a single (non-
null) result. -
queryRequiredSingleJSON(
String query, [dynamic args]) → Future< String> -
Executes a query, returning the result as a JSON encoded
String. -
querySingle(
String query, [dynamic args]) → Future -
Executes a query, returning a single (possibly
null) result. -
querySingleJSON(
String query, [dynamic args]) → Future< String> -
Executes a query, returning the result as a JSON encoded
String. -
querySQL(
String query, [dynamic args]) → Future< List> -
Executes a SQL query, returning a
Listof results. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited